import { useEffect, useState } from "react"
import { WX_APPID } from "@/common/constant"
import useUserInfo from "./useUserInfo"
import Taro, { useRouter } from "@tarojs/taro"
import { Login } from "@/api/login"


export default () => {
    const {setToken, setSessionKey, setUserInfo, userInfo} = useUserInfo()

    useEffect(() => {
        console.log('userInfo::',userInfo.token)
    }, [userInfo])

    //登录请求
    const {fetchData} = Login()
    const loginRequest = async (code) => {
       const {data, success} = await fetchData({js_code: code})
       if(success) {
            setToken(data.token)
            setSessionKey(data.session_key)
       } else {
           Taro.showToast({
               title:'登录失败',
               icon:"none"
           })
       }
    }

    //微信登录
    const wxLogin = () => {
        Taro.login({
            success: function async (res) {
                if (res.code) {
                    loginRequest(res.code)
                } else {
                    console.log('登录失败！' + res.errMsg)
                }
            },
            fail: function(e) {
                console.log('登录失败！::',e)
            }
        })
    }

    const router = useRouter()
    //登录加checkLogin检查
    const checkLogin = () => {
        if(!userInfo.token) {
                wxLogin()
                if(router.path != '/pages/index/index') {
                    Taro.reLaunch({
                        url: '/pages/index/index'
                    })
                }
        } else {
            Taro.checkSession({
                fail () {
                    wxLogin()
                }
            })
        }
        
    }

    //获取用户头像等信息数据
    const getUserInfo =  () => {
        Taro.getUserProfile({
            desc: '用于完善会员资料',
            success: (res) => {
                Taro.request({
                    url: 'https://dev.zzfzyc.com/lymarket/v1/mall/user/decrypt',
                    method: 'POST',
                    data: {
                        session_key: userInfo.sessionkey,
                        raw_data: res.rawData,
                        signature: res.signature,
                        encrypted_data: res.encryptedData,
                        iv: res.iv
                    },
                    header: {
                        platform: 6,
                        Authorization: userInfo.token,
                        Appid: WX_APPID
                    },
                    success: (e) => {
                        setUserInfo({})
                    },
                    fail: (e) => {
                        console.log(e)
                    }
                })
            }
        })
    }

    return {
        checkLogin,
        wxLogin,
        getUserInfo
    }
}
